@@ -12,13 +12,13 @@ from .so4gp import gen_apriori_candidates
 from .so4gp import gen_aco_candidates
 from .so4gp import inv
 
-from .so4gp import acogps
-from .so4gp import clugps
-from .so4gp import hcgps
-from .so4gp import gagps
+from .so4gp import aco_graank
+from .so4gp import clu_bfs
+from .so4gp import hc_graank
+from .so4gp import ga_graank
 from .so4gp import graank
-from .so4gp import psogps
-from .so4gp import rsgps
+from .so4gp import pso_graank
+from .so4gp import rs_graank
 
 from .so4gp import analyze_gps
 from .so4gp import get_num_cores
